==> zio-aws-amplifybackend_3-5.17.126.1-sources.jar: zio/aws/amplifybackend/model/GetBackendApiModelsRequest.scala <==
package zio.aws.amplifybackend.model
import zio.aws.amplifybackend.model.primitives.__string
import zio.ZIO
import zio.aws.core.BuilderHelper
import scala.jdk.CollectionConverters.*
final case class GetBackendApiModelsRequest(
    appId: __string,
    backendEnvironmentName: __string,
    resourceName: __string
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.amplifybackend.model.GetBackendApiModelsRequest = {
    import GetBackendApiModelsRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.amplifybackend.model.GetBackendApiModelsRequest
      .builder()
      .appId(__string.unwrap(appId): java.lang.String)
      .backendEnvironmentName(
        __string.unwrap(backendEnvironmentName): java.lang.String
      )
      .resourceName(__string.unwrap(resourceName): java.lang.String)
      .build()
  }
  def asReadOnly
      : zio.aws.amplifybackend.model.GetBackendApiModelsRequest.ReadOnly =
    zio.aws.amplifybackend.model.GetBackendApiModelsRequest
      .wrap(buildAwsValue())
}
object GetBackendApiModelsRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.amplifybackend.model.GetBackendApiModelsRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.amplifybackend.model.GetBackendApiModelsRequest =
      zio.aws.amplifybackend.model
        .GetBackendApiModelsRequest(appId, backendEnvironmentName, resourceName)
    def appId: __string
    def backendEnvironmentName: __string
    def resourceName: __string
    def getAppId: ZIO[Any, Nothing, __string] = ZIO.succeed(appId)
    def getBackendEnvironmentName: ZIO[Any, Nothing, __string] =
      ZIO.succeed(backendEnvironmentName)
    def getResourceName: ZIO[Any, Nothing, __string] = ZIO.succeed(resourceName)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.amplifybackend.model.GetBackendApiModelsRequest
  ) extends zio.aws.amplifybackend.model.GetBackendApiModelsRequest.ReadOnly {
    override val appId: __string =
      zio.aws.amplifybackend.model.primitives.__string(impl.appId())
    override val backendEnvironmentName: __string =
      zio.aws.amplifybackend.model.primitives
        .__string(impl.backendEnvironmentName())
    override val resourceName: __string =
      zio.aws.amplifybackend.model.primitives.__string(impl.resourceName())
  }
  def wrap(
      impl: software.amazon.awssdk.services.amplifybackend.model.GetBackendApiModelsRequest
  ): zio.aws.amplifybackend.model.GetBackendApiModelsRequest.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-amplifybackend_3-5.19.31.5-sources.jar: zio/aws/amplifybackend/model/GetBackendApiModelsRequest.scala <==
package zio.aws.amplifybackend.model
import zio.aws.amplifybackend.model.primitives.__string
import zio.ZIO
import zio.aws.core.BuilderHelper
import scala.jdk.CollectionConverters.*
final case class GetBackendApiModelsRequest(
    appId: __string,
    backendEnvironmentName: __string,
    resourceName: __string
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.amplifybackend.model.GetBackendApiModelsRequest = {
    import GetBackendApiModelsRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.amplifybackend.model.GetBackendApiModelsRequest
      .builder()
      .appId(appId: java.lang.String)
      .backendEnvironmentName(backendEnvironmentName: java.lang.String)
      .resourceName(resourceName: java.lang.String)
      .build()
  }
  def asReadOnly
      : zio.aws.amplifybackend.model.GetBackendApiModelsRequest.ReadOnly =
    zio.aws.amplifybackend.model.GetBackendApiModelsRequest
      .wrap(buildAwsValue())
}
object GetBackendApiModelsRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.amplifybackend.model.GetBackendApiModelsRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.amplifybackend.model.GetBackendApiModelsRequest =
      zio.aws.amplifybackend.model
        .GetBackendApiModelsRequest(appId, backendEnvironmentName, resourceName)
    def appId: __string
    def backendEnvironmentName: __string
    def resourceName: __string
    def getAppId: ZIO[Any, Nothing, __string] = ZIO.succeed(appId)
    def getBackendEnvironmentName: ZIO[Any, Nothing, __string] =
      ZIO.succeed(backendEnvironmentName)
    def getResourceName: ZIO[Any, Nothing, __string] = ZIO.succeed(resourceName)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.amplifybackend.model.GetBackendApiModelsRequest
  ) extends zio.aws.amplifybackend.model.GetBackendApiModelsRequest.ReadOnly {
    override val appId: __string = impl.appId(): __string
    override val backendEnvironmentName: __string =
      impl.backendEnvironmentName(): __string
    override val resourceName: __string = impl.resourceName(): __string
  }
  def wrap(
      impl: software.amazon.awssdk.services.amplifybackend.model.GetBackendApiModelsRequest
  ): zio.aws.amplifybackend.model.GetBackendApiModelsRequest.ReadOnly =
    new Wrapper(impl)
}
